Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(37)

Unified Diff: components/user_manager/user_manager.h

Issue 718673002: New user type introduced. Combines regular and supervised features. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Logical expression fixed. Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/user_manager/user_manager.h
diff --git a/components/user_manager/user_manager.h b/components/user_manager/user_manager.h
index 656ff62f0dde068930f2688d5879c11ef560b49d..2935a6ef246643a0785114c0fca089a5cc4dc950 100644
--- a/components/user_manager/user_manager.h
+++ b/components/user_manager/user_manager.h
@@ -253,8 +253,11 @@ class USER_MANAGER_EXPORT UserManager {
// Returns true if at least one user has signed in.
virtual bool IsUserLoggedIn() const = 0;
- // Returns true if we're logged in as a regular user.
- virtual bool IsLoggedInAsRegularUser() const = 0;
+ // Returns true if we're logged in as a user with gaia account.
bartfab (slow) 2014/11/27 12:51:51 Nit: s/with/with a/
+ virtual bool IsLoggedInAsUserWithGaiaAccount() const = 0;
+
+ // Returns true if we're logged in as a regular supervised user.
+ virtual bool IsLoggedInAsRegularSupervisedUser() const = 0;
// Returns true if we're logged in as a demo user.
virtual bool IsLoggedInAsDemoUser() const = 0;

Powered by Google App Engine
This is Rietveld 408576698